==> mathjinni_0.6.20080612-2.tar.gz: mathjinni-0.6.20080612/src/Calc.h <==
#ifndef CALC_H
#define CALC_H

/*
  MathJinni - A simple formular calculator
  Copyright (C) 2007  Tim Teulings

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <Lum/Object.h>

#include <Lum/Model/Action.h>
#include <Lum/Model/String.h>
#include <Lum/Model/Table.h>

#include <Lum/Combo.h>

#include "Parser.h"

class Calc : public Lum::Component
{
public:
  class Prefs : public Lum::Component::Prefs
  {
  public:
    Prefs();
    void Initialize();
  };

private:
  Lum::Model::ActionRef    calculate;
  Lum::Model::ListTableRef history;
  Lum::Model::StringRef    calcInput;
  Lum::TextEditCombo       *comboInput;
  Lum::Model::StringRef    calcResult;

  Parser                   parser;

private:
  void Calculate();

public:
  Calc();
  ~Calc();

  void CalcSize();

  void Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg);
};

#endif

==> mathjinni_0.9.20090520-1.tar.gz: mathjinni-0.9.20090520/src/Calc.h <==
#ifndef CALC_H
#define CALC_H

/*
  MathJinni - A simple formular calculator
  Copyright (C) 2007  Tim Teulings

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <Lum/Object.h>

#include <Lum/Model/Action.h>
#include <Lum/Model/String.h>
#include <Lum/Model/Table.h>

#include <Lum/Combo.h>

#include "Configuration.h"
#include "Parser.h"

class Calc : public Lum::Component, public ConfigPlugin
{
private:
  Lum::Model::ActionRef      calculate;
  Lum::Model::StringTableRef history;
  Lum::Model::StringRef      calcInput;
  Lum::TextEditCombo         *comboInput;
  Lum::Model::StringRef      calcResult;

  Parser                     parser;

private:
  void Calculate();

public:
  Calc();

  void CalcSize();

  void Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg);

  void LoadConfig(Lum::Config::Node *top);
  void StoreConfig(Lum::Config::Node *top);
};

#endif
